// Alchemy Definition / Craft System Script v.0.2 by SickLab

using System;
using Server.Scripts.Items;
using Server.Scripts.Items.Potions;

namespace Server.Scripts.CraftSystems
{
	public class DefAlchemy : CraftSystem
	{
		public override SkillName MainSkill
		{
			get	{ return SkillName.Alchemy;	}
		}

		public override string GumpTitle
		{
			get { return "ALCHEMY MENU"; }
		}

		public override int GumpTitlePos
		{
			get { return 195; }
		}

		private static CraftSystem m_CraftSystem;

		public static CraftSystem CraftSystem
		{
			get
			{
				if ( m_CraftSystem == null )
					m_CraftSystem = new DefAlchemy();

				return m_CraftSystem;
			}
		}

		private DefAlchemy() : base( 1, 2, 3.1 )
		{
		}

		public override bool CanCraft( Mobile from )
		{
			// This function is mainly here for the blacksmithy skill.  Wich need to
			// check if we'r near a forge/anvil to craft an item.  But this function can
			// be modified for your own shard need.  If you want Potions to be craftable
			// in a Laboratory only, you could modify this function in the Alchemy class.
			return true;
		}

		public override void PlayCraftEffect( Mobile from )
		{
			from.PlaySound( 0x242 );
		}

		public override void PlayEndingEffect( Mobile from, bool failed, bool lostMaterial )
		{
			if ( failed )
			{
				from.SendLocalizedMessage( 500287 ); // You fail to create a useful potion.

				from.AddToBackpack( new Bottle() );
			}
			else
			{
				from.PlaySound( 0x240 ); // Sound of a filling bottle
				from.SendLocalizedMessage( 500279 ); // You poor the potion into a bottle...
			}
		}

		public override void InitCraftList()
		{
			int index = -1;
			
			// Agility Potion
			index = AddCraft( typeof( AgilityPotion ), "Agility", "Agility", 15.1, 30.0, typeof( Bloodmoss ), "Bloodmoss", 1, 501904 );
			AddRes( index, typeof ( Bottle ), "Empty Bottle", 1, 500315);
			index = AddCraft( typeof( GreaterAgilityPotion ), "Agility", "Greater Agility", 35.1, 60.0, typeof( Bloodmoss ), "Bloodmoss", 3, 501904 );
			AddRes( index, typeof ( Bottle ), "Empty Bottle", 1, 500315 );
			
			// Cure Potion
			index = AddCraft( typeof( LesserCurePotion ), "Cure", "Lesser Cure", 0.0, 20.0, typeof( Garlic ), "Garlic", 1, 501904 );
			AddRes( index, typeof ( Bottle ), "Empty Bottle", 1, 500315 );
			index = AddCraft( typeof( CurePotion ), "Cure", "Cure", 25.1, 50.0, typeof( Garlic ), "Garlic", 3, 501904 );
			AddRes( index, typeof ( Bottle ), "Empty Bottle", 1, 500315 );
			index = AddCraft( typeof( GreaterCurePotion ), "Cure", "Greater Cure", 65.1, 100.0, typeof( Garlic ), "Garlic", 6, 501904 );
			AddRes( index, typeof ( Bottle ), "Empty Bottle", 1, 500315 );
			
			// Heal Potion
			index = AddCraft( typeof( LesserHealPotion ), "Heal", "Lesser Heal", 0.0, 30.0, typeof( Ginseng ), "Ginseng", 1, 501904 );
			AddRes( index, typeof ( Bottle ), "Empty Bottle", 1, 500315 );
			index = AddCraft( typeof( HealPotion ), "Heal", "Heal", 15.1, 60.0, typeof( Ginseng ), "Ginseng", 3, 501904 );
			AddRes( index, typeof ( Bottle ), "Empty Bottle", 1, 500315 );
			index = AddCraft( typeof( GreaterHealPotion ), "Heal", "Greater Heal", 55.1, 100.0, typeof( Ginseng ), "Ginseng", 6, 501904 );
			AddRes( index, typeof ( Bottle ), "Empty Bottle", 1, 500315 );
			
			// Poison Potion
			index = AddCraft( typeof( LesserPoisonPotion ), "Poison", "Lesser Poison", 0.0, 20.0, typeof( Nightshade ), "Nightshade", 1, 501904 );
			AddRes( index, typeof ( Bottle ), "Empty Bottle", 1, 500315 );
			index = AddCraft( typeof( PoisonPotion ), "Poison", "Poison", 15.1, 30.0, typeof( Nightshade ), "Nightshade", 2, 501904 );
			AddRes( index, typeof ( Bottle ), "Empty Bottle", 1, 500315 );
			index = AddCraft( typeof( GreaterPoisonPotion ), "Poison", "Greater Poison", 55.1, 100.0, typeof( Nightshade ), "Nightshade", 4, 501904 );
			AddRes( index, typeof ( Bottle ), "Empty Bottle", 1, 500315 );
			index = AddCraft( typeof( DeadlyPoisonPotion ), "Poison", "Deadly Poison", 90.1, 100.0, typeof( Nightshade ), "Nightshade", 8, 501904 );
			AddRes( index, typeof ( Bottle ), "Empty Bottle", 1, 500315 );
			
			// Refresh Potion
			index = AddCraft( typeof( RefreshPotion ), "Refresh", "Refresh", 15.1, 30.0, typeof( BlackPearl ), "Black Pearl", 1, 501904 );
			AddRes( index, typeof ( Bottle ), "Empty Bottle", 1, 500315 );
			index = AddCraft( typeof( TotalRefreshPotion ), "Refresh", "Total Refresh", 25.1, 60.0, typeof( BlackPearl ), "Black Pearl", 5, 501904 );
			AddRes( index, typeof ( Bottle ), "Empty Bottle", 1, 500315 );
			
			// Strength Potion
			index = AddCraft( typeof( StrengthPotion ), "Strength", "Strength", 25.1, 50.0, typeof( MandrakeRoot ), "Mandrake Root", 2, 501904 );
			AddRes( index, typeof ( Bottle ), "Empty Bottle", 1, 500315 );
			index = AddCraft( typeof( GreaterStrengthPotion ), "Strength", "Greater Strength", 45.1, 90.0, typeof( MandrakeRoot ), "Mandrake Root", 5, 501904 );
			AddRes( index, typeof ( Bottle ), "Empty Bottle", 1, 500315 );
		}
	}
}