// Bowcraft - Fletching Definition / Craft System Script v.0.2 by SickLab

using System;
using Server.Items;
using Server.Scripts.Items;
using Server.Scripts.Items.Weapons.Ranged;

namespace Server.Scripts.CraftSystems
{
	public class DefBowFletching : CraftSystem
	{
		public override SkillName MainSkill
		{
			get	{ return SkillName.Fletching; }
		}

		public override string GumpTitle
		{
			get { return "BOWCRAFT / FLETCHING MENU"; }
		}

		public override int GumpTitlePos
		{
			get { return 120; }
		}

		private static CraftSystem m_CraftSystem;

		public static CraftSystem CraftSystem
		{
			get
			{
				if ( m_CraftSystem == null )
					m_CraftSystem = new DefBowFletching();

				return m_CraftSystem;
			}
		}

		private DefBowFletching() : base( 2, 4, 1.7 )
		{
		}

		public override bool CanCraft( Mobile from )
		{
			// This function is mainly here for the blacksmithy skill.  Wich need to
			// check if we'r near a forge/anvil to craft an item.  But this function can
			// be modified for your own shard need.  If you want Potions to be craftable
			// in a Laboratory only, you could modify this function in the Alchemy class.
			return true;
		}

		public override void PlayCraftEffect( Mobile from )
		{
			if ( from.Body.Type == BodyType.Human && !from.Mounted )
				from.Animate( 33, 5, 1, true, false, 0 );

			from.PlaySound( 0x55 );
		}

		public override void PlayEndingEffect( Mobile from, bool failed, bool lostMaterial )
		{
			if ( failed )
			{
				if ( lostMaterial )
				{
					from.SendLocalizedMessage( 1044043 ); // You failed to create the item, and some of your materials are lost.
				}
				else
				{
					from.SendLocalizedMessage( 1044157 ); // You failed to create the item, but no materials were lost.
				}
			}
			else
			{
				from.SendLocalizedMessage( 1044154 ); // You create the item
			}
		}

		public override void InitCraftList()
		{
			int index = -1;
			
			// Materials
			AddCraft( typeof( Kindling ), "Materials", "Kindling", 0.0, 20.0, typeof( Log ), "Log", 1 );
			AddCraft( typeof( Shaft ), "Materials", "Shaft", 0.0, 20.0, typeof( Log ), "Log", 1 );

			// Ammunition
			index = AddCraft( typeof( Arrow ), "Ammunition", "Arrow", 0.0, 20.0, typeof( Shaft ), "Shaft", 1 );
			AddRes( index, typeof( Feather ), "Feather", 1 );
			index = AddCraft( typeof( Bolt ), "Ammunition", "Bolt", 0.0, 20.0, typeof( Shaft ), "Shaft", 1 );
			AddRes( index, typeof( Feather ), "Feather", 1 );

			// Weapons
			index = AddCraft( typeof( Bow ), "Weapons", "Bow", 30.0, 60.0, typeof( Log ), "Log", 7 );
			index = AddCraft( typeof( Crossbow ), "Weapons", "Crossbow", 60.0, 95.0, typeof( Log ), "Log", 7 );
			index = AddCraft( typeof( HeavyCrossbow ), "Weapons", "Heavy Crossbow", 90.0, 100.0, typeof( Log ), "Log", 10 );
		}
	}
}