// Carpentry Definition / Craft System Script v.0.2 by SickLab

using System;
using Server.Scripts.Items;
using Server.Scripts.Items.Weapons.Staves;
using Server.Scripts.Items.Instruments;

namespace Server.Scripts.CraftSystems
{
	public class DefCarpentry : CraftSystem
	{
		public override SkillName MainSkill
		{
			get	{ return SkillName.Carpentry;	}
		}

		public override string GumpTitle
		{
			get { return "CARPENTRY MENU"; }
		}

		public override int GumpTitlePos
		{
			get { return 175; }
		}

		private static CraftSystem m_CraftSystem;

		public static CraftSystem CraftSystem
		{
			get
			{
				if ( m_CraftSystem == null )
					m_CraftSystem = new DefCarpentry();

				return m_CraftSystem;
			}
		}

		private DefCarpentry() : base(1, 2, 3.0)
		{
		}

		public override bool CanCraft( Mobile from )
		{
			// This function is mainly here for the blacksmithy skill.  Wich need to
			// check if we'r near a forge/anvil to craft an item.  But this function can
			// be modified for your own shard need.  If you want Potions to be craftable
			// in a Laboratory only, you could modify this function in the Alchemy class.
			return true;
		}

		public override void PlayCraftEffect( Mobile from )
		{
			if ( from.Body.Type == BodyType.Human && !from.Mounted )
				from.Animate( 9, 5, 1, true, false, 0 );

			from.PlaySound( 0x23D );
		}

		public override void PlayEndingEffect( Mobile from, bool failed, bool lostMaterial )
		{
			if ( failed )
			{
				if ( lostMaterial) 
				{
					from.SendLocalizedMessage( 1044043 ); // You failed to create the item, and some of your materials are lost.
				}
				else
				{
					from.SendLocalizedMessage( 1044157 ); // You failed to create the item, but no materials were lost.
				}
			}
			else
			{
				from.SendLocalizedMessage( 1044154 ); // You create the item
			}
		}

		public override void InitCraftList()
		{
			int index = -1;
			
			//Staves
			AddCraft( typeof( ShepherdsCrook ), "Staves", "Shepherd's Crook", 78.9, 100.0, typeof( Log ), "Log", 7 );
			AddCraft( typeof( QuarterStaff ), "Staves", "Quarter Staff", 73.6, 100.0, typeof( Log ), "Log", 6 );
			AddCraft( typeof( GnarledStaff ), "Staves", "Gnarled Staff", 78.9, 100.0, typeof( Log ), "Log", 7 );
			AddCraft( typeof( BlackStaff ), "Staves", "Black Staff", 85.9, 100.0, typeof( Log ), "Log", 7 );

			// Instruments
			index = AddCraft( typeof( LapHarp ), "Instruments", "Lap Harp", 63.1, 100.0, typeof( Log ), "Log", 20 );
			AddSkill( index, SkillName.Musicianship, 45.0, 50.0 );
			AddRes( index, typeof( Cloth ), "Cloth", 10 );

			index = AddCraft( typeof( Harp ), "Instruments", "Standing Harp", 78.9, 100.0, typeof( Log ), "Log", 35 );
			AddSkill( index, SkillName.Musicianship, 45.0, 50.0 );
			AddRes( index, typeof( Cloth ), "Cloth", 15 );
			
			index = AddCraft( typeof( Drums ), "Instruments", "Drum", 57.8, 100.0, typeof( Log ), "Log", 20 );
			AddSkill( index, SkillName.Musicianship, 45.0, 50.0 );
			AddRes( index, typeof( Cloth ), "Cloth", 10 );
			
			index = AddCraft( typeof( Lute ), "Instruments", "Lute", 68.4, 100.0, typeof( Log ), "Log", 25 );
			AddSkill( index, SkillName.Musicianship, 45.0, 50.0 );
			AddRes( index, typeof( Cloth ), "Cloth", 10 );
			
			index = AddCraft( typeof( Tambourine ), "Instruments", "Tambourine", 57.8, 100.0, typeof( Log ), "Log", 15 );
			AddSkill( index, SkillName.Musicianship, 45.0, 50.0 );
			AddRes( index, typeof( Cloth ), "Cloth", 10 );
			
			index = AddCraft( typeof( TambourineTassel ), "Instruments", "Tambourine (tassel)", 57.8, 100.0, typeof( Log ), "Log", 15 );
			AddSkill( index, SkillName.Musicianship, 45.0, 50.0 );
			AddRes( index, typeof( Cloth ), "Cloth", 15 );
		}
	}
}