using System;
using System.Collections;
using Server;
using Server.Network;
using Server.Gumps;

namespace Server.Scripts.HelpSystem
{
	public class PageQueueGump : Gump
	{
		private PageEntry[] m_List;

		public PageQueueGump() : base( 50, 50 )
		{
			Add( new GumpPage( 0 ) );
			//Add( new GumpBackground( 0, 0, 410, 448, 9200 ) );
			Add( new GumpImageTiled( 0, 0, 410, 448, 0x52 ) );
			Add( new GumpAlphaRegion( 1, 1, 408, 446 ) );

			Add( new GumpLabel( 180, 12, 2100, "Page Queue" ) );

			m_List = (PageEntry[])PageQueue.List.ToArray( typeof( PageEntry ) );

			if ( m_List.Length > 0 )
			{
				Add( new GumpPage( 1 ) );

				for ( int i = 0; i < m_List.Length; ++i )
				{
					if ( i >= 5 && (i % 5) == 0 )
					{
						Add( new GumpButton( 368, 12, 0xFA5, 0xFA7, 0, GumpButtonType.Page, (i / 5) + 1 ) );
						Add( new GumpLabel( 298, 12, 2100, "Next Page" ) );
						Add( new GumpPage( (i / 5) + 1 ) );
						Add( new GumpButton( 12, 12, 0xFAE, 0xFB0, 0, GumpButtonType.Page, (i / 5) ) );
						Add( new GumpLabel( 48, 12, 2100, "Previous Page" ) );
					}

					PageEntry e = m_List[i];

					string html = String.Format( "[{0}] {1} <basefont color=#{2:X6}>[<u>{3}</u>]</basefont>", e.Type.ToString(), e.Message, e.Handler == null ? 0xFF0000 : 0xFF, e.Handler == null ? "Unhandled" : "Handling" );

					Add( new GumpHtml( 12, 44 + ((i % 5) * 80), 350, 70, html, true, true ) );
					Add( new GumpButton( 370, 44 + ((i % 5) * 80) + 24, 0xFA5, 0xFA7, i + 1, GumpButtonType.Reply, 0 ) );
				}
			}
			else
			{
				Add( new GumpLabel( 12, 44, 2100, "The page queue is empty." ) );
			}
		}

		public override void OnResponse( NetState state, RelayInfo info )
		{
			if ( info.ButtonID >= 1 && info.ButtonID <= m_List.Length )
			{
				PageEntryGump g = new PageEntryGump( state.Mobile, m_List[info.ButtonID - 1] );

				g.SendTo( state );
			}
		}
	}

	public class PageEntryGump : Gump
	{
		private PageEntry m_Entry;
		private Mobile m_Mobile;

		private static int[] m_AccessLevelHues = new int[]
			{
				2100,
				2122,
				2117,
				2129,
				2415
			};

		public PageEntryGump( Mobile m, PageEntry entry ) : base( 50, 50 )
		{
			m_Mobile = m;
			m_Entry = entry;

			int buttons = 0;

			int bottom = 292;

			Add( new GumpPage( 0 ) );

			Add( new GumpImageTiled( 0, 0, 410, 332, 0x52 ) );
			Add( new GumpAlphaRegion( 1, 1, 408, 330 ) );

			Add( new GumpLabel( 18, 18, 2100, "Sent:" ) );
			Add( new GumpLabelCropped( 128, 18, 264, 20, 2100, entry.Sent.ToString() ) );

			Add( new GumpLabel( 18, 38, 2100, "Sender:" ) );
			Add( new GumpLabelCropped( 128, 38, 264, 20, 2100, String.Format( "{0} {1} [{2}]", entry.Sender.Name, entry.Sender.Location, entry.Sender.Map ) ) );

			if ( entry.Sender != m )
			{
				Add( new GumpButton( 18, bottom - (buttons * 22), 0xFA5, 0xFA7, 1, GumpButtonType.Reply, 0 ) );
				Add( new GumpLabel( 52, bottom - (buttons++ * 22), 2100, "Go to Sender" ) );
			}

			Add( new GumpLabel(  18, 58, 2100, "Handler:" ) );

			if ( entry.Handler == null )
			{
				Add( new GumpLabelCropped( 128, 58, 264, 20, 2100, "Unhandled" ) );

				Add( new GumpButton( 18, bottom - (buttons * 22), 0xFB1, 0xFB3, 5, GumpButtonType.Reply, 0 ) );
				Add( new GumpLabel( 52, bottom - (buttons++ * 22), 2100, "Delete Page" ) );

				Add( new GumpButton( 18, bottom - (buttons * 22), 0xFB7, 0xFB9, 4, GumpButtonType.Reply, 0 ) );
				Add( new GumpLabel( 52, bottom - (buttons++ * 22), 2100, "Handle Page" ) );
			}
			else
			{
				Add( new GumpLabelCropped( 128, 58, 264, 20, m_AccessLevelHues[(int)entry.Handler.AccessLevel], entry.Handler.Name ) );

				if ( entry.Handler != m )
				{
					Add( new GumpButton( 18, bottom - (buttons * 22), 0xFA5, 0xFA7, 2, GumpButtonType.Reply, 0 ) );
					Add( new GumpLabel( 52, bottom - (buttons++ * 22), 2100, "Go to Handler" ) );
				}
				else
				{
					Add( new GumpButton( 18, bottom - (buttons * 22), 0xFA2, 0xFA4, 6, GumpButtonType.Reply, 0 ) );
					Add( new GumpLabel( 52, bottom - (buttons++ * 22), 2100, "Abandon Page" ) ); 

					Add( new GumpButton( 18, bottom - (buttons * 22), 0xFB7, 0xFB9, 7, GumpButtonType.Reply, 0 ) );
					Add( new GumpLabel( 52, bottom - (buttons++ * 22), 2100, "Page Handled" ) );
				}
			}

			Add( new GumpLabel(  18, 78, 2100, "Page Location:" ) );
			Add( new GumpLabelCropped( 128, 78, 264, 20, 2100, String.Format( "{0} [{1}]", entry.PageLocation, entry.PageMap ) ) );

			Add( new GumpButton( 18, bottom - (buttons * 22), 0xFA5, 0xFA7, 3, GumpButtonType.Reply, 0 ) );
			Add( new GumpLabel( 52, bottom - (buttons++ * 22), 2100, "Go to Page Location" ) );

			Add( new GumpLabel(  18, 98, 2100, "Page Type:" ) );
			Add( new GumpLabelCropped( 128, 98, 264, 20, 2100, entry.Type.ToString() ) );

			Add( new GumpLabel(  18, 118, 2100, "Message:" ) );
			Add( new GumpHtml(  128, 118, 250, 100, entry.Message, true, true ) );
		}

		public void Resend( NetState state )
		{
			PageEntryGump g = new PageEntryGump( m_Mobile, m_Entry );

			g.SendTo( state );
		}

		public override void OnResponse( NetState state, RelayInfo info )
		{
			switch ( info.ButtonID )
			{
				case 0: // close
				{
					if ( m_Entry.Handler != state.Mobile )
					{
						PageQueueGump g = new PageQueueGump();

						g.SendTo( state );
					}

					break;
				}
				case 1: // go to sender
				{
					Mobile m = state.Mobile;

					m.Location = m_Entry.Sender.Location;
					m.Map = m_Entry.Sender.Map;

					m.SendMessage( "You have been teleported to that pages sender." );

					Resend( state );

					break;
				}
				case 2: // go to handler
				{
					Mobile m = state.Mobile;
					Mobile h = m_Entry.Handler;

					if ( h != null )
					{
						m.Location = h.Location;
						m.Map = h.Map;

						m.SendMessage( "You have been teleported to that pages handler." );
					}
					else
					{
						m.SendMessage( "Nobody is handling that page." );
					}

					Resend( state );

					break;
				}
				case 3: // go to page location
				{
					Mobile m = state.Mobile;

					m.Location = m_Entry.PageLocation;
					m.Map = m_Entry.PageMap;

					state.Mobile.SendMessage( "You have been teleported to the original page location." );

					Resend( state );

					break;
				}
				case 4: // handle page
				{
					if ( m_Entry.Handler == null )
					{
						m_Entry.Handler = state.Mobile;

						state.Mobile.SendMessage( "You are now handling the page." );
					}
					else
					{
						state.Mobile.SendMessage( "Someone is already handling that page." );
					}

					Resend( state );

					break;
				}
				case 5: // delete page
				{
					if ( m_Entry.Handler == null )
					{
						PageQueue.Remove( m_Entry );

						state.Mobile.SendMessage( "You delete the page." );

						PageQueueGump g = new PageQueueGump();

						g.SendTo( state );
					}
					else
					{
						state.Mobile.SendMessage( "Someone is handling that page, it can not be deleted." );

						Resend( state );
					}

					break;
				}
				case 6: // abandon page
				{
					if ( m_Entry.Handler == state.Mobile )
					{
						state.Mobile.SendMessage( "You abandon the page." );

						m_Entry.Handler = null;
					}
					else
					{
						state.Mobile.SendMessage( "You are not handling that page." );
					}

					Resend( state );

					break;
				}
				case 7: // page handled
				{
					if ( m_Entry.Handler == state.Mobile )
					{
						PageQueue.Remove( m_Entry );

						m_Entry.Handler = null;

						state.Mobile.SendMessage( "You mark the page as handled, and remove it from the queue." );

						PageQueueGump g = new PageQueueGump();

						g.SendTo( state );
					}
					else
					{
						state.Mobile.SendMessage( "You are not handling that page." );

						Resend( state );
					}

					break;
				}
			}
		}
	}
}