// Cooking System Script v.1.0 by SickLab (2002-09-29)

using System;
using Server.Targeting;
using Server.Items;
using Server.Network;

namespace Server.Scripts.Items
{
	public abstract class CookableFood : Item
	{
		private int m_CookingLevel;

		[CommandProperty( AccessLevel.GameMaster )]
		public int CookingLevel
		{
			get
			{
				return m_CookingLevel;
			}
			set
			{
				m_CookingLevel = value;
			}
		}

		public CookableFood( int itemID, int cookingLevel ) : base( itemID )
		{
			m_CookingLevel = cookingLevel;
		}

		public CookableFood( Serial serial ) : base( serial )
		{
		}

		public abstract Food Cook();

		public override void Serialize( GenericWriter writer )
		{
			base.Serialize( writer );

			writer.Write( (int) 1 ); // version
			// Version 1
			writer.Write( (int) m_CookingLevel );

		}

		public override void Deserialize( GenericReader reader )
		{
			base.Deserialize( reader );

			int version = reader.ReadInt();
			switch ( version )
			{
				case 1:
				{
					m_CookingLevel = reader.ReadInt();
					break;
				}
			}
		}

		public override void OnDoubleClick( Mobile from )
		{
			if ( !Movable )
				return;

			from.Target = new InternalTarget( this );
		}

		private class InternalTarget : Target
		{
			private CookableFood m_Item;

			public InternalTarget( CookableFood item ) : base( 1, false, TargetFlags.None )
			{
				m_Item = item;
			}

			protected override void OnTarget( Mobile from, object targeted )
			{
				if ( m_Item.Deleted ) return;

				if ( targeted is Campfire )
				{
					from.PlaySound( 0x225 );

					m_Item.Consume();

					InternalTimer t = new InternalTimer( from, (Campfire)targeted, m_Item );
					t.Start();
				}
			}

			private class InternalTimer : Timer
			{
				private Mobile m_From;
				private Campfire m_Campfire;
				private CookableFood m_CookableFood;
			
				public InternalTimer( Mobile from, Campfire campfire, CookableFood cookableFood ) : base( TimeSpan.FromSeconds( 5.0 ) )
				{
					m_From = from;
					m_Campfire = campfire;
					m_CookableFood = cookableFood;
				}

				protected override void OnTick()
				{
					if ( m_From.GetDistanceToSqrt( m_Campfire ) > 3 )
					{
						m_From.SendLocalizedMessage( 500686 ); // You burn the food to a crisp! It's ruined.
						return;
					}

					if ( m_From.CheckSkill( SkillName.Cooking, m_CookableFood.CookingLevel, 0 ) )
					{
						Food cookedFood = m_CookableFood.Cook();

						if ( m_From.AddToBackpack( cookedFood ) )
							m_From.PlaySound( 0x57 );
					}
					else
					{
						m_From.SendLocalizedMessage( 500686 ); // You burn the food to a crisp! It's ruined.
					}
				}
			}
		}
	}


	// ********** RawRibs **********
	public class RawRibs : CookableFood
	{
		[Constructable]
		public RawRibs() : base( 0x9F1, 10 )
		{
			Weight = 1.0;
			Stackable = true;
		}

		public RawRibs( Serial serial ) : base( serial )
		{
		}

		public override void Serialize( GenericWriter writer )
		{
			base.Serialize( writer );

			writer.Write( (int) 0 ); // version
		}

		public override void Deserialize( GenericReader reader )
		{
			base.Deserialize( reader );

			int version = reader.ReadInt();
		}

		public override Food Cook()
		{
			return new Ribs();
		}
	}


	// ********** RawLambLeg **********
	public class RawLambLeg : CookableFood
	{
		[Constructable]
		public RawLambLeg() : base( 0x1609, 10 )
		{
			Weight = 1.0;
			Stackable = true;
		}

		public RawLambLeg( Serial serial ) : base( serial )
		{
		}

		public override void Serialize( GenericWriter writer )
		{
			base.Serialize( writer );

			writer.Write( (int) 0 ); // version
		}

		public override void Deserialize( GenericReader reader )
		{
			base.Deserialize( reader );

			int version = reader.ReadInt();
		}

		public override Food Cook()
		{
			return new LambLeg();
		}
	}



	// ********** RawChickenLeg **********
	public class RawChickenLeg : CookableFood
	{
		[Constructable]
		public RawChickenLeg() : base( 0x1607, 10 )
		{
			Weight = 1.0;
			Stackable = true;
		}

		public RawChickenLeg( Serial serial ) : base( serial )
		{
		}

		public override void Serialize( GenericWriter writer )
		{
			base.Serialize( writer );

			writer.Write( (int) 0 ); // version
		}

		public override void Deserialize( GenericReader reader )
		{
			base.Deserialize( reader );

			int version = reader.ReadInt();
		}

		public override Food Cook()
		{
			return new ChickenLeg();
		}
	}


	// ********** RawBird **********
	public class RawBird : CookableFood
	{
		[Constructable]
		public RawBird() : base( 0x9B9, 10 )
		{
			Weight = 1.0;
			Stackable = true;
		}

		public RawBird( Serial serial ) : base( serial )
		{
		}

		public override void Serialize( GenericWriter writer )
		{
			base.Serialize( writer );

			writer.Write( (int) 0 ); // version
		}

		public override void Deserialize( GenericReader reader )
		{
			base.Deserialize( reader );

			int version = reader.ReadInt();
		}

		public override Food Cook()
		{
			return new CookedBird();
		}
	}


	// ********** UnbakedPeachCobbler **********
	public class UnbakedPeachCobbler : CookableFood
	{
		[Constructable]
		public UnbakedPeachCobbler() : base( 0x1042, 25 )
		{
			Weight = 1.0;
		}

		public UnbakedPeachCobbler( Serial serial ) : base( serial )
		{
		}

		public override void Serialize( GenericWriter writer )
		{
			base.Serialize( writer );

			writer.Write( (int) 0 ); // version
		}

		public override void Deserialize( GenericReader reader )
		{
			base.Deserialize( reader );

			int version = reader.ReadInt();
		}

		public override void OnSingleClick( Mobile from )
		{
			this.LabelTo( from, 1041335 );
		}

		public override Food Cook()
		{
			return new PeachCobbler();
		}
	}

	// ********** UnbakedApplePie **********
	public class UnbakedApplePie : CookableFood
	{
		[Constructable]
		public UnbakedApplePie() : base( 0x1042, 25 )
		{
			Weight = 1.0;
		}

		public UnbakedApplePie( Serial serial ) : base( serial )
		{
		}

		public override void Serialize( GenericWriter writer )
		{
			base.Serialize( writer );

			writer.Write( (int) 0 ); // version
		}

		public override void Deserialize( GenericReader reader )
		{
			base.Deserialize( reader );

			int version = reader.ReadInt();
		}

		public override void OnSingleClick( Mobile from )
		{
			this.LabelTo( from, 1041336 );
		}

		public override Food Cook()
		{
			return new ApplePie();
		}
	}

	// ********** UncookedPizza **********
	public class UncookedPizza : CookableFood
	{
		[Constructable]
		public UncookedPizza() : base( 0x1040, 20 )
		{
			Weight = 1.0;
			Hue = 51;
		}

		public UncookedPizza( Serial serial ) : base( serial )
		{
		}

		public override void Serialize( GenericWriter writer )
		{
			base.Serialize( writer );

			writer.Write( (int) 0 ); // version
		}

		public override void Deserialize( GenericReader reader )
		{
			base.Deserialize( reader );

			int version = reader.ReadInt();
		}

		public override void OnSingleClick( Mobile from )
		{
			this.LabelTo( from, 1024227 );
		}

		public override Food Cook()
		{
			return new Pizza();
		}
	}

	// ********** UnbakedQuiche **********
	public class UnbakedQuiche : CookableFood
	{
		[Constructable]
		public UnbakedQuiche() : base( 0x1042, 25 )
		{
			Weight = 1.0;
		}

		public UnbakedQuiche( Serial serial ) : base( serial )
		{
		}

		public override void Serialize( GenericWriter writer )
		{
			base.Serialize( writer );

			writer.Write( (int) 0 ); // version
		}

		public override void Deserialize( GenericReader reader )
		{
			base.Deserialize( reader );

			int version = reader.ReadInt();
		}

		public override void OnSingleClick( Mobile from )
		{
			this.LabelTo( from, 1041339 );
		}

		public override Food Cook()
		{
			return new Quiche();
		}
	}

	// ********** Eggs **********
	public class Eggs : CookableFood
	{
		[Constructable]
		public Eggs() : base( 0x9B5, 15 )
		{
			Weight = 0.5;
		}

		public Eggs( Serial serial ) : base( serial )
		{
		}

		public override void Serialize( GenericWriter writer )
		{
			base.Serialize( writer );

			writer.Write( (int) 0 ); // version
		}

		public override void Deserialize( GenericReader reader )
		{
			base.Deserialize( reader );

			int version = reader.ReadInt();
		}

		public override Food Cook()
		{
			return new FriedEggs();
		}
	}

	// ********** CookieMix **********
	public class CookieMix : CookableFood
	{
		[Constructable]
		public CookieMix() : base( 0x103F, 20 )
		{
			Weight = 1.0;
		}

		public CookieMix( Serial serial ) : base( serial )
		{
		}

		public override void Serialize( GenericWriter writer )
		{
			base.Serialize( writer );

			writer.Write( (int) 0 ); // version
		}

		public override void Deserialize( GenericReader reader )
		{
			base.Deserialize( reader );

			int version = reader.ReadInt();
		}

		public override Food Cook()
		{
			return new Cookies();
		}
	}

	// ********** CakeMix **********
	public class CakeMix : CookableFood
	{
		[Constructable]
		public CakeMix() : base( 0x103F, 40 )
		{
			Weight = 1.0;
		}

		public CakeMix( Serial serial ) : base( serial )
		{
		}

		public override void Serialize( GenericWriter writer )
		{
			base.Serialize( writer );

			writer.Write( (int) 0 ); // version
		}

		public override void Deserialize( GenericReader reader )
		{
			base.Deserialize( reader );

			int version = reader.ReadInt();
		}

		public override void OnSingleClick( Mobile from )
		{
			this.LabelTo( from, 1041002 );
		}

		public override Food Cook()
		{
			return new Cake();
		}
	}
}
