using System;
using Server;

namespace Server.Scripts.Items.Potions
{
	public class CureLevelInfo
	{
		private Poison m_Poison;
		private double m_Chance;

		public Poison Poison
		{
			get
			{
				return m_Poison;
			}
		}

		public double Chance
		{
			get
			{
				return m_Chance;
			}
		}

		public CureLevelInfo( Poison poison, double chance )
		{
			m_Poison = poison;
			m_Chance = chance;
		}
	}

	public abstract class BaseCurePotion : BasePotion
	{
		public abstract CureLevelInfo[] LevelInfo{ get; }

		public BaseCurePotion( PotionEffect effect ) : base( 0xF07, effect )
		{
		}

		public BaseCurePotion( Serial serial ) : base( serial )
		{
		}

		public override void Serialize( GenericWriter writer )
		{
			base.Serialize( writer );

			writer.Write( (int) 0 ); // version
		}

		public override void Deserialize( GenericReader reader )
		{
			base.Deserialize( reader );

			int version = reader.ReadInt();
		}

		public void DoCure( Mobile from )
		{
			bool cure = false;

			CureLevelInfo[] info = LevelInfo;

			for ( int i = 0; i < info.Length; ++i )
			{
				CureLevelInfo li = info[i];

				if ( li.Poison == from.Poison && li.Chance >= Utility.RandomDouble() )
				{
					cure = true;
					break;
				}
			}

			if ( cure )
				from.Poison = null;

			from.SendLocalizedMessage( cure ? 500231 : 500232 );
		}

		public override void Drink( Mobile from )
		{
			if ( from.Poisoned )
			{
				DoCure( from );

				BasePotion.PlayDrinkEffect( from );

				from.PlaySound( 0x1E0 );
				Effects.SendTargetEffect( from, 0x373A, 16 );

				this.Delete();
			}
			else
			{
				from.SendMessage( "You decide against drinking this poition, as you are not poisoned." );
			}
		}
	}
}