using System;
using Server.Targeting;
using Server.Items;

namespace Server.SkillHandlers
{
	public class Stealing
	{
		public static void Initialize()
		{
			SkillInfo.Table[33].Callback = new SkillUseCallback( OnUse );
		}

		private class StealingTarget : Target
		{
			private Mobile m_Thief;

			public StealingTarget( Mobile thief ) : base ( 1, false, TargetFlags.None )
			{
				m_Thief = thief;
			}

			private Item TryStealItem( Item toSteal )
			{
				Item stolen = null;

				if ( !m_Thief.CanSee( toSteal ) )
				{
					m_Thief.SendLocalizedMessage( 500237 ); // Target can not be seen.
				}
				else if ( !toSteal.Movable )
				{
					m_Thief.SendLocalizedMessage( 502710 ); // You can't steal that!
				}
				else if ( !m_Thief.InRange( toSteal.GetWorldLocation(), 1 ) )
				{
					m_Thief.SendLocalizedMessage( 502703 ); // You must be standing next to an item to steal it.
				}
				else if ( toSteal.Parent is Mobile )
				{
					m_Thief.SendLocalizedMessage( 1005585 ); // You cannot steal items which are equiped.
				}
				else if ( toSteal.RootParent == m_Thief )
				{
					m_Thief.SendLocalizedMessage( 502704 ); // You catch yourself red-handed.
				}
				else
				{
					if ( toSteal.Weight >= 10.0 )
					{
						m_Thief.SendMessage( "That is too heavy to steal." );
					}
					else
					{
						if ( toSteal.Amount > 1 )
						{
							int amount = Utility.Random( 1, (int)((m_Thief.Skills[SkillName.Stealing].Value / 10.0) / toSteal.Weight) );

							if ( amount >= toSteal.Amount )
							{
								if ( m_Thief.CheckSkill( SkillName.Stealing, 0, toSteal.Weight*toSteal.Amount*10 ) )
									stolen = toSteal;
							}
							else
							{
								if ( m_Thief.CheckSkill( SkillName.Stealing, 0, toSteal.PileWeight*10 ) )
								{
									stolen = toSteal.Dupe( amount );
									toSteal.Amount -= amount;
								}
							}
						}
						else
						{
							if ( m_Thief.CheckSkill( SkillName.Stealing, 0, toSteal.Weight*10 ) )
								stolen = toSteal;
						}

						if ( stolen != null )
						{
							m_Thief.SendLocalizedMessage( 502724 ); // You succesfully steal the item.
						} 
						else 
						{
							m_Thief.SendLocalizedMessage( 502723 ); // You fail to steal the item.
						}
					}
				}

				return stolen;
			}

			protected override void OnTarget( Mobile from, object target )
			{
				Item stolen = null;

				//TODO: Flagging

				//Skill advancement done in TryStealItem()
				if ( target is Item )
				{
					stolen = TryStealItem( (Item)target );
				} 
				else if ( target is Mobile )
				{
					Container pack = ((Mobile)target).Backpack;

					if ( pack != null && pack.Items.Count > 0 )
					{
						int randomIndex = Utility.Random( pack.Items.Count );

						stolen = TryStealItem( (Item) pack.Items[randomIndex] );
					}
				} 
				else 
				{
					m_Thief.SendLocalizedMessage( 502710 ); // You can't steal that!
				}

				if ( stolen != null )
				{
					Container pack = from.Backpack;

					if ( pack == null || !pack.OnDragDrop( from, stolen ) )
					{
						stolen.MoveToWorld( from.Location, from.Map );
					}
				}
			}
		}

		public static TimeSpan OnUse( Mobile m )
		{
			m.Target = new Stealing.StealingTarget( m );
			m.RevealingAction();

			m.SendLocalizedMessage( 502698 ); // Which item do you want to steal?

			return TimeSpan.FromSeconds( 10.0 );
		}
	}
}