// Invisibility Spell Script v.1.0 by SickLab

using System;
using Server;
using Server.Targeting;

namespace Server.Spells.Sixth
{
	public class InvisibilitySpell : Spell
	{
		private static SpellInfo m_Info = new SpellInfo(
				"Invisibility", "An Lor Xen",
				SpellCircle.Sixth,
				Reagent.Bloodmoss,
				Reagent.Nightshade
			);

		public InvisibilitySpell( Mobile caster, Server.Items.SpellScroll scroll ) : base( caster, scroll, m_Info )
		{
		}

		public override void OnCast()
		{
			Caster.Target = new InternalTarget( this );
		}

		public void Target( Mobile m )
		{
			if ( !Caster.CanSee( m ) )
			{
				Caster.SendLocalizedMessage( 500237 ); // Target can not be seen.
			}
			else if ( CheckBSequence( m ) )
			{
				if ( Caster != m )
					Caster.Direction = Caster.GetDirectionTo( m );

				m.PlaySound( 0x203 );
				Effects.SendTargetEffect( m, 0x376A, 16 );

				m.Hidden = true;

				TimeSpan duration = TimeSpan.FromSeconds( Caster.Skills[SkillName.Magery].Value * 1.2 ); // 120% of magery

				new InternalTimer( m, duration ).Start();
			}

			FinishSequence();
		}

		private class InternalTimer : Timer
		{
			private Mobile m_Mobile;

			public InternalTimer( Mobile m, TimeSpan duration ) : base( duration )
			{
				m_Mobile = m;
			}

			protected override void OnTick()
			{
				m_Mobile.Hidden = false;
			}
		}

		public class InternalTarget : Target
		{
			private InvisibilitySpell m_Owner;

			public InternalTarget( InvisibilitySpell owner ) : base( 12, false, TargetFlags.Beneficial )
			{
				m_Owner = owner;
			}

			protected override void OnTarget( Mobile from, object o )
			{
				if ( o is Mobile )
				{
					m_Owner.Target( (Mobile)o );
				}
			}

			protected override void OnTargetFinish( Mobile from )
			{
				m_Owner.FinishSequence();
			}
		}
	}
}